==> polyv-java-live-sdk-1.2.0-sources.jar: net/polyv/live/v1/entity/channel/operate/LiveSonChannelInfoResponse.java <==
package net.polyv.live.v1.entity.channel.operate;

import java.util.Date;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.experimental.Accessors;

/**
 * 查询角色信息返回体
 * @author: sadboy
 **/
@Data
@Accessors(chain = true)
@ApiModel("查询角色信息返回体")
public class LiveSonChannelInfoResponse {
    
    /**
     * 助教/嘉宾账号
     */
    @ApiModelProperty(name = "account", value = "助教/嘉宾账号", required = false)
    private String account;
    
    /**
      *  {@code POLYV用户ID，和保利威官网一致，获取路径：官网->登录->直播（开发设置）}
     */
    @ApiModelProperty(name = "userId", value = "POLYV用户ID，和保利威官网一致，获取路径：官网->登录->直播（开发设置）", required = false)
    private String userId;
    
    /**
     * 频道号
     */
    @ApiModelProperty(name = "channelId", value = "频道号", required = false)
    private String channelId;
    
    /**
     * 角色密码
     */
    @ApiModelProperty(name = "passwd", value = "角色密码", required = false)
    private String passwd;
    
    /**
     * 角色名称
     */
    @ApiModelProperty(name = "nickname", value = "角色名称", required = false)
    private String nickname;
    
    /**
     * 角色流名（单独使用无效）
     */
    @ApiModelProperty(name = "stream", value = "角色流名（单独使用无效）", required = false)
    private String stream;
    
    /**
     * 角色状态
     */
    @ApiModelProperty(name = "status", value = "角色状态", required = false)
    private String status;
    
    /**
     * 创建角色时间
     */
    @ApiModelProperty(name = "createdTime", value = "创建角色时间", required = false)
    private Date createdTime;
    
    /**
     * 角色最后修改时间
     */
    @ApiModelProperty(name = "lastModified", value = "角色最后修改时间", required = false)
    private Date lastModified;
    
    /**
     * 频道中所有角色序号
     */
    @ApiModelProperty(name = "sort", value = "频道中所有角色序号", required = false)
    private Integer sort;
    
    /**
     * 角色头像
     */
    @ApiModelProperty(name = "avatar", value = "角色头像", required = false)
    private String avatar;
    
    /**
     * 角色翻页权限（只能一个角色有）
     */
    @ApiModelProperty(name = "pageTurnEnabled", value = "助教翻页权限（只能一个角色有）", required = false)
    private String pageTurnEnabled;
    
    /**
     * 发布公告权限(Y/N)
     */
    @ApiModelProperty(name = "notifyEnabled", value = "发布公告权限(Y/N)", required = false)
    private String notifyEnabled;
    
    /**
     * 开启签到权限(Y/N)
     */
    @ApiModelProperty(name = "checkinEnabled", value = "开启签到权限(Y/N)", required = false)
    private String checkinEnabled;
    
    /**
     * 发起投票(Y/N)
     */
    @ApiModelProperty(name = "voteEnabled", value = "发起投票(Y/N)", required = false)
    private String voteEnabled;
    
    /**
     * 角色角色
     */
    @ApiModelProperty(name = "role", value = "角色<br>assistant：助教<br>guest：嘉宾", required = false)
    private String role;
    
    /**
     * 角色推流地址（角色推流请参考后台导播台使用）
     */
    @ApiModelProperty(name = "pushUrl", value = "子频道推流地址（子频道推流请参考后台导播台使用）", required = false)
    private String pushUrl;

}

==> polyv-java-live-sdk-2.1.1.2-sources.jar: net/polyv/live/v1/entity/channel/operate/LiveSonChannelInfoResponse.java <==
package net.polyv.live.v1.entity.channel.operate;

import java.util.Date;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.experimental.Accessors;

/**
 * 查询角色信息返回体
 * @author: sadboy
 **/
@Data
@Accessors(chain = true)
@ApiModel("查询角色信息返回体")
public class LiveSonChannelInfoResponse {
    
    /**
     * 助教/嘉宾账号
     */
    @ApiModelProperty(name = "account", value = "助教/嘉宾账号", required = false)
    private String account;
    
    /**
      *  {@code POLYV用户ID，和保利威官网一致，获取路径：官网->登录->直播（开发设置）}
     */
    @ApiModelProperty(name = "userId", value = "POLYV用户ID，和保利威官网一致，获取路径：官网->登录->直播（开发设置）", required = false)
    private String userId;
    
    /**
     * 频道号
     */
    @ApiModelProperty(name = "channelId", value = "频道号", required = false)
    private String channelId;
    
    /**
     * 角色密码
     */
    @ApiModelProperty(name = "passwd", value = "角色密码", required = false)
    private String passwd;
    
    /**
     * 角色名称
     */
    @ApiModelProperty(name = "nickname", value = "角色名称", required = false)
    private String nickname;
    
    /**
     * 角色流名（单独使用无效）
     */
    @ApiModelProperty(name = "stream", value = "角色流名（单独使用无效）", required = false)
    private String stream;
    
    /**
     * 角色状态
     */
    @ApiModelProperty(name = "status", value = "角色状态", required = false)
    private String status;
    
    /**
     * 创建角色时间
     */
    @ApiModelProperty(name = "createdTime", value = "创建角色时间", required = false)
    private Date createdTime;
    
    /**
     * 角色最后修改时间
     */
    @ApiModelProperty(name = "lastModified", value = "角色最后修改时间", required = false)
    private Date lastModified;
    
    /**
     * 频道中所有角色序号
     */
    @ApiModelProperty(name = "sort", value = "频道中所有角色序号", required = false)
    private Integer sort;
    
    /**
     * 角色头像
     */
    @ApiModelProperty(name = "avatar", value = "角色头像", required = false)
    private String avatar;
    
    /**
     * 角色翻页权限（只能一个角色有）
     */
    @ApiModelProperty(name = "pageTurnEnabled", value = "助教翻页权限（只能一个角色有）", required = false)
    private String pageTurnEnabled;
    
    /**
     * 发布公告权限(Y/N)
     */
    @ApiModelProperty(name = "notifyEnabled", value = "发布公告权限(Y/N)", required = false)
    private String notifyEnabled;
    
    /**
     * 开启签到权限(Y/N)
     */
    @ApiModelProperty(name = "checkinEnabled", value = "开启签到权限(Y/N)", required = false)
    private String checkinEnabled;
    
    /**
     * 发起投票(Y/N)
     */
    @ApiModelProperty(name = "voteEnabled", value = "发起投票(Y/N)", required = false)
    private String voteEnabled;
    
    /**
     * 角色角色
     */
    @ApiModelProperty(name = "role", value = "角色<br>Assistant：助教<br>Guest：嘉宾", required = false)
    private String role;
    
    /**
     * 角色推流地址（角色推流请参考后台导播台使用）
     */
    @ApiModelProperty(name = "pushUrl", value = "子频道推流地址（子频道推流请参考后台导播台使用）", required = false)
    private String pushUrl;

}
